# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: operations-init.j2

"""Auto-generated package that contains models used by the Analytics Game Telemetry."""

__version__ = "1.25.1"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"
